
# Slot: abstract


an abstract class is a high level class or slot that is typically used to group common slots together and cannot be directly instantiated.

URI: [linkml:abstract](https://w3id.org/linkml/abstract)


## Domain and Range

[Definition](Definition.md) &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)
